@@ -47,7 +47,7 @@ type instance V (a,b,c) = V a
 
 type instance V (a -> b)   = V b
 type instance V [a]        = V a
-type instance V (Option a) = V a
+type instance V (Maybe a) = V a
 type instance V (Set a)    = V a
 type instance V (Map k a)  = V a
 
@@ -63,7 +63,7 @@ type instance N (a,b,c) = N a
 
 type instance N (a -> b)   = N b
 type instance N [a]        = N a
-type instance N (Option a) = N a
+type instance N (Maybe a) = N a
 type instance N (Set a)    = N a
 type instance N (Map k a)  = N a
 
@@ -71,7 +71,7 @@ type instance N (Deletable m) = N m
 type instance N (Split m)     = N m
 type instance N (m :+: n)     = N m
 
--- | Conveient type alias to retrieve the vector type associated with an
+-- | Convenient type alias to retrieve the vector type associated with an
 --   object's vector space. This is usually used as @Vn a ~ v n@ where @v@ is
 --   the vector space and @n@ is the numerical field.
 type Vn a = V a (N a)
